@@ -1,6 +1,5 @@
-
 #' LEfSer plot cladogram
-#' 
+#'
 #' \code{lefserPlotClad} plots a cladogram from the results of
 #' \code{lefserClades}.
 #'
@@ -16,6 +15,7 @@
 #' It can accept several options, e.g., c("p", "c").
 #'
 #' @importFrom ggtree %<+%
+#' @importFrom dplyr mutate case_when relocate
 #'
 #' @return A ggtree object.
 #' @export
@@ -31,7 +31,10 @@
 #' resCl <- lefserClades(relab = z14_input, classCol = "study_condition")
 #' ggt <- lefserPlotClad(df = resCl)
 lefserPlotClad <- function(
-        df, colors = c("c", "l", "g"), showTipLabels = FALSE, showNodeLabels = "p"
+    df,
+    colors = c("c", "l", "g"),
+    showTipLabels = FALSE,
+    showNodeLabels = "p"
 ) {
     inputClass <- class(df)[1]
     if (inputClass != "lefser_df_clades") {
@@ -41,42 +44,45 @@ lefserPlotClad <- function(
             call. = FALSE
         )
     }
-    
+
     df$features <- .extractTips(df$features)
-    
+
     colors <- .selectPalette(colors)
     tree <- attr(df, "tree")
     controlVar <- attr(df, "lclassf")
     caseVar <- attr(df, "case")
-    
+
     res <- df |>
-        dplyr::mutate(
-            sample = dplyr::case_when(
+        mutate(
+            sample = case_when(
                 ## This assumes positive values always mean enriched in
                 ## the case condition.
                 .data[["scores"]] > 0 ~ .env[["caseVar"]],
                 TRUE ~ .env[["controlVar"]]
             )
         ) |>
-        dplyr::mutate(abs = abs(.data[["scores"]])) |>
+        mutate(abs = abs(.data[["scores"]])) |>
         as.data.frame()
-    
+
     labels <- c(tree$tip.label, tree$node.label)
     res$node <- match(res$features, labels)
-    dat <- dplyr::relocate(res, .data$node)
-    
+    dat <- relocate(res, .data$node)
+
     internalNodes <- ape::Ntip(tree) + 1:ape::Nnode(tree)
-    
-    collapseThem <- purrr::map_int(internalNodes, ~ {
-        chNods <- treeio::offspring(.data = tree, .node = .x, type = "tips")
-        if (any(chNods %in% dat$node)) {
-            return(NA)
-        } else {
-            return(.x)
+
+    collapseThem <- purrr::map_int(
+        internalNodes,
+        ~ {
+            chNods <- treeio::offspring(.data = tree, .node = .x, type = "tips")
+            if (any(chNods %in% dat$node)) {
+                return(NA)
+            } else {
+                return(.x)
+            }
         }
-    }) |>
+    ) |>
         purrr::discard(is.na)
-    
+
     nodLab <- match.arg(
         arg = showNodeLabels,
         choices = c("p", "c", "o", "f", "g", "s", "t"),
@@ -84,46 +90,56 @@ lefserPlotClad <- function(
     )
     nodLabRgx <- paste0("[", paste0(nodLab, collapse = ""), "]__")
     treeData <- dat |>
-        dplyr::mutate(abs = round(.data$abs, 1)) |> 
-        dplyr::mutate(
-            showNodeLabs = dplyr::case_when(
+        mutate(abs = round(.data$abs, 1)) |>
+        mutate(
+            showNodeLabs = case_when(
                 grepl(nodLabRgx, features) ~ features,
                 TRUE ~ NA
             )
         )
     minval <- floor(min(treeData$abs, na.rm = TRUE))
     maxval <- floor(max(treeData$abs, na.rm = TRUE))
-    
+
     gt <- ggtree::ggtree(
-        tree, layout = "circular",  branch.length = "none", size = 0.2
-    ) %<+% treeData
-    
+        tree,
+        layout = "circular",
+        branch.length = "none",
+        size = 0.2
+    ) %<+%
+        treeData
+
     gt <- gt +
         ggtree::geom_tippoint(
-            mapping = ggtree::aes(fill = sample, size = abs), shape = 21,
-            na.rm=TRUE
+            mapping = ggtree::aes(fill = sample, size = abs),
+            shape = 21,
+            na.rm = TRUE
         ) +
         ggtree::geom_nodepoint(
-            mapping = ggtree::aes(fill = sample, size = abs), shape = 21,
+            mapping = ggtree::aes(fill = sample, size = abs),
+            shape = 21,
             na.rm = TRUE
         )
-    
+
     if (showTipLabels) {
-        gt <- gt + 
+        gt <- gt +
             ggtree::geom_tiplab(
-                mapping = ggtree::aes(label = features), size = 2,
-                geom = "text", na.rm=TRUE
+                mapping = ggtree::aes(label = features),
+                size = 2,
+                geom = "text",
+                na.rm = TRUE
             )
     }
-    
+
     gt2 <- gt +
         ggrepel::geom_label_repel(
             mapping = ggtree::aes(label = .data$showNodeLabs),
             na.rm = TRUE
         ) +
         ggtree::scale_fill_manual(
-            values = colors, breaks = c(controlVar, caseVar),
-            name = "Sample", na.value = NA
+            values = colors,
+            breaks = c(controlVar, caseVar),
+            name = "Sample",
+            na.value = NA
         ) +
         ggplot2::scale_size(
             name = "Absolute\nLDA score",
@@ -131,10 +147,9 @@ lefserPlotClad <- function(
             # range = range(seq_along(seq(minval, maxval, 1))),
             range = c(minval, maxval),
             breaks = seq(minval, maxval, 1)
-            
         ) +
         ggtree::theme(legend.position = "right")
-    
+
     for (i in collapseThem) {
         gt2 <- withCallingHandlers(
             ggtree::collapse(gt2, node = i),
